__author__ = 'Sujit Mandal'
#Date : 22-03-202
from setuptools import setup 

def readme():
    with open('README.md') as files:
        README = files.read()

    return(README)

setup(
    name = 'system-slash',
    version = '0.0.3',
    description = 'It will find operating system and then generate slash as per system required.',
    long_description = readme(),
    long_description_content_type = 'text/markdown',
    url = 'https://github.com/sujitmandal/system-slash',
    author = 'Sujit Mandal',
    author_email = 'mandals974@gmail.com',
    license = 'MIT',
    classifiers = [
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.0',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],

    packages = ['SystemSlash'],
    include_package_data = True,
)


import platform

#This programe is create by Sujit Mandal
# Github: https://github.com/sujitmandal
# Pypi : https://pypi.org/user/sujitmandal/
# LinkedIn : https://www.linkedin.com/in/sujit-mandal-91215013a/


def slash():
    if platform.system() == 'Linux':
        system = '/'
    elif platform.system() == 'Windows':
        syste = ' \ '
        system = syste.strip()

    return(system)

if __name__ == "__main__":
    slash()